run_command

Function run_command 

pub async fn run_command(
    command: Commands,
    client: AnytypeClient,
    output: CommandOutput,
) -> Result<()>
Execute a backup command with a client and output contract configured by the parent application.

The parent application is responsible for rejecting output combinations the requested command cannot honor; see command_is_interactive.