pub struct BackupCreateArgs {Show 15 fields
pub space: String,
pub objects: Option<String>,
pub format: ExportFormatArg,
pub mode: BackupModeArg,
pub since: Option<String>,
pub since_mode: SinceModeArg,
pub types: Option<Vec<String>>,
pub dir: Option<PathBuf>,
pub dest: Option<PathBuf>,
pub prefix: Option<String>,
pub include_nested: bool,
pub include_files: bool,
pub include_archived: bool,
pub include_backlinks: bool,
pub include_properties: bool,
}Fields
space: StringSpace name or id. Name must be unambiguous.
objects: Option<String>Object IDs source path, or ‘-’ to read from stdin. Omit for full-space backup.
format: ExportFormatArgExport format
mode: BackupModeArgBackup mode
since: Option<String>Incremental lower bound timestamp.
Accepts RFC3339 with timezone/offset, or no-timezone local time (assumed local timezone).
Example UTC values: 2026-01-12T10:11:22Z, 2026-01-12 10:11:22 UTC, 2026-01-12T10:11:22+00:00.
since_mode: SinceModeArgIncremental window mode
types: Option<Vec<String>>Include only these object types (comma-separated keys and/or ids)
dir: Option<PathBuf>Parent directory where the archive will be created (default: current directory)
dest: Option<PathBuf>Output archive path to create
prefix: Option<String>Archive name prefix used with –dir/default parent; ignored when –dest is used
include_nested: boolInclude linked (nested) objects in export payload
include_files: boolInclude file objects and file binaries in export payload
include_archived: boolInclude archived objects in backup selection
include_backlinks: boolInclude backlinks in export payload
include_properties: boolInclude properties and schema in markdown export output